@@ -1,11 +1,19 @@
-import requests
 import os
 
+import requests
+
 from .extract_handler import ExtractHandler
 
-class HttpAdapter():
+
+class HttpAdapter:
     @staticmethod
-    def download(dest_path: str, file_name: str = None, url: str = None, extract: bool = False, **kwargs):
+    def download(
+        dest_path: str,
+        file_name: str = None,
+        url: str = None,
+        extract: bool = False,
+        **kwargs
+    ):
         # TODO check if file name format is matched with downloaded file
 
         assert isinstance(url, str), "url must be string but found:{}".format(type(url))
@@ -13,8 +21,12 @@ class HttpAdapter():
         file_name = url.split("/")[-1] if file_name is None else file_name
         res = requests.get(url)
 
-        assert res.status_code == 200, "wrong status code \
-            recived:{} with response:{}".format(res.status_code, res.content)
+        assert (
+            res.status_code == 200
+        ), "wrong status code \
+            recived:{} with response:{}".format(
+            res.status_code, res.content
+        )
 
         file_path = os.path.join(dest_path, file_name)
 
@@ -24,6 +36,7 @@ class HttpAdapter():
         with open(file_path, "wb") as foo:
             foo.write(res.content)
 
-        if not extract: return
+        if not extract:
+            return
 
-        ExtractHandler.extract(file_path, dest_path, **kwargs)
\ No newline at end of file
+        ExtractHandler.extract(file_path, dest_path, **kwargs)
