@@ -1,22 +1,10 @@
-__all__ = [
-    "list_pretrained_models",
-    "download_pretrained_model",
-    "list_archs",
-    "list_arch_configs",
-    "get_arch_config"
-]
-
-from typing import List,Dict
 import os
-
-from ..utils.config import (
-    discover_archs,
-    get_arch_cls,
-    get_registry
-)
-from ..utils.cache import get_model_cache_dir
+from typing import Dict, List
 
 from ..adapter import download_object
+from ..utils.cache import get_model_cache_dir
+from ..utils.config import discover_archs, get_arch_cls, get_registry
+
 
 def list_pretrained_models() -> List[str]:
     """Returns available pretrained model names
@@ -30,6 +18,7 @@ def list_pretrained_models() -> List[str]:
     """
     return list(get_registry().keys())
 
+
 def download_pretrained_model(model: str, target_path: str = None) -> str:
     """Downloads pretrained model to given target path,
     if target path is None, it will use model cache path.
@@ -46,19 +35,21 @@ def download_pretrained_model(model: str, target_path: str = None) -> str:
         target_path = get_model_cache_dir()
     registry = get_registry()
     assert model in registry, f"given model: {model} is not in the registry"
-    assert os.path.exists(target_path), f"given target path: {target_path} does not exists"
+    assert os.path.exists(
+        target_path
+    ), f"given target path: {target_path} does not exists"
     assert os.path.isdir(target_path), "given target path must be directory not a file"
 
     adapter = registry[model]["adapter"]
     file_name = registry[model]["adapter"]["kwargs"]["file_name"]
-    model_path = os.path.join(target_path,file_name)
+    model_path = os.path.join(target_path, file_name)
 
     if not os.path.isfile(model_path):
         # download if model not exists
-        download_object(adapter['type'],
-            dest_path=target_path, **adapter['kwargs'])
+        download_object(adapter["type"], dest_path=target_path, **adapter["kwargs"])
     return model_path
 
+
 def list_archs() -> List[str]:
     """Returns available architecture names
 
@@ -72,6 +63,7 @@ def list_archs() -> List[str]:
     """
     return [arch for arch, _ in discover_archs()]
 
+
 def list_arch_configs(arch: str) -> List[str]:
     """Returns available architecture configurations as list
 
@@ -88,6 +80,7 @@ def list_arch_configs(arch: str) -> List[str]:
     """
     return list(get_arch_cls(arch).__CONFIGS__.keys())
 
+
 def get_arch_config(arch: str, config: str) -> Dict:
     """Returns configuration dictionary for given arch and config names
 
@@ -104,4 +97,4 @@ def get_arch_config(arch: str, config: str) -> Dict:
 
     """
     arch_cls = get_arch_cls(arch)
-    return arch_cls.__CONFIGS__[config].copy()
\ No newline at end of file
+    return arch_cls.__CONFIGS__[config].copy()
