@@ -1,9 +1,5 @@
-__all__ = [
-    "WiderFaceAP",
-    "AveragePrecision",
-    "AverageRecall"
-]
-
-from .widerface_ap import WiderFaceAP
 from .ap import AveragePrecision
 from .ar import AverageRecall
+from .widerface_ap import WiderFaceAP
+
+__all__ = ["WiderFaceAP", "AveragePrecision", "AverageRecall"]
