@@ -1,20 +1,24 @@
 import random
-import numpy as np
-from typing import Tuple, Dict
+from typing import Dict, Tuple
 
-class RandomHorizontalFlip():
+import numpy as np
+
+
+class RandomHorizontalFlip:
     """Applies random horizontal flip for the image and updated boxes"""
 
     def __init__(self, p: float = 0.5):
-        assert p >= 0 and p <= 1.0, "given `p` is not valid, must be between 0 and 1 but found: {}".format(p)
+        assert (
+            p >= 0 and p <= 1.0
+        ), "given `p` is not valid, must be between 0 and 1 but found: {}".format(p)
         self.p = p
 
     def __call__(self, img: np.ndarray, targets: Dict = {}) -> Tuple[np.ndarray, Dict]:
         if random.random() > self.p:
             return (img, targets)
-        
+
         if len(img.shape) == 3:
-            nimg = img[:, ::-1,:]
+            nimg = img[:, ::-1, :]
         elif len(img.shape) == 2:
             nimg = img[:, ::-1]
         else:
