@@ -1,7 +1,9 @@
 from typing import Dict, Tuple
+
 import numpy as np
 
-class Compose():
+
+class Compose:
     """Compose given transforms"""
 
     def __init__(self, *transforms):
@@ -12,4 +14,4 @@ class Compose():
         for transform in self.transforms:
             img, targets = transform(img, targets=targets)
 
-        return (img, targets)
\ No newline at end of file
+        return (img, targets)
