@@ -1,8 +1,10 @@
 import math
-import numpy as np
-from typing import Tuple, Dict
+from typing import Dict, Tuple
 
-class FaceDiscarder():
+import numpy as np
+
+
+class FaceDiscarder:
     """Discard face boxes using min and max scale"""
 
     def __init__(self, min_face_size: int = 0, max_face_size: int = math.inf):
@@ -13,11 +15,15 @@ class FaceDiscarder():
 
         if "target_boxes" in targets:
             target_boxes = targets["target_boxes"]
-            face_scales = (target_boxes[:, [2,3]] - target_boxes[:, [0,1]]).max(axis=1)
-            mask = (face_scales >= self.min_face_size) & (face_scales <= self.max_face_size)
+            face_scales = (target_boxes[:, [2, 3]] - target_boxes[:, [0, 1]]).max(
+                axis=1
+            )
+            mask = (face_scales >= self.min_face_size) & (
+                face_scales <= self.max_face_size
+            )
             targets["target_boxes"] = target_boxes[mask]
 
             if "ignore_flags" in targets:
                 targets["ignore_flags"] = targets["ignore_flags"][mask]
 
-        return (img, targets)
\ No newline at end of file
+        return (img, targets)
