@@ -1,11 +1,14 @@
-import numpy as np
-from typing import Tuple, Union, List, Dict
+from typing import Dict, List, Tuple, Union
 
-class Normalize():
+import numpy as np
+
+
+class Normalize:
     """Normalizes the image with given `mean` and `std`. (img - mean) / std"""
 
-    def __init__(self, mean: Union[List, Tuple, float] = 0,
-            std: Union[List, Tuple, float]=1):
+    def __init__(
+        self, mean: Union[List, Tuple, float] = 0, std: Union[List, Tuple, float] = 1
+    ):
         self.mean = mean
         self.std = std
 
@@ -14,4 +17,4 @@ class Normalize():
         img = img - self.mean
         img = img / self.std
 
-        return (img, targets)
\ No newline at end of file
+        return (img, targets)
